@@ -14,7 +14,7 @@ DRBL_SCRIPT_PATH="${DRBL_SCRIPT_PATH:-/opt/drbl/}"
 . $DRBL_SCRIPT_PATH/sbin/drbl-conf-functions
 
 # Settings
-SL_ISO_URL_EXAMPLE="http://prdownloads.sourceforge.net/clonezilla/clonezilla-live-1.2.5-6-i686.iso"
+SL_ISO_URL_EXAMPLE="http://downloads.sourceforge.net/clonezilla/clonezilla-live-1.2.6-24-i686.iso"
 # The method for netboot's root file system. "fetch" means the client will download the filesystem.squashfs from tftpd server, "nfsroot" means client will mount the nfs server. By default we use fetch. "nfsroot" only works for Debian-live based system (e.g. Clonezilla live, GParted live...)
 rootfs_location="fetch"
 # Force to update the PXELinux config file
@@ -423,7 +423,11 @@ install_SL(){
     exit 1
   fi
   
-  if [ -z "$(file $SL_ISO | grep -i "ISO 9660 CD-ROM filesystem data")" ]; then
+  # Program file might give different results:
+  # ISO 9660 CD-ROM filesystem data # file vesion 5.03
+  # x86 boot sector # file version 4.10
+  if [ -z "$(LC_ALL=C file -L $SL_ISO | grep -i "ISO 9660 CD-ROM filesystem data")" ] && \
+     [ -z "$(LC_ALL=C file -L $SL_ISO | grep -i "x86 boot sector")" -a "$(echo $SL_ISO | grep -iE "\.iso")" ]; then
     [ "$BOOTUP" = "color" ] && $SETCOLOR_FAILURE
     echo "$SL_ISO is not an ISO 9660 CD-ROM filesystem data file!"
     [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
@@ -548,8 +552,8 @@ install_SL(){
     # In RH9: vmlinuz-2.4.20-28.9smp: x86 boot sector
     if [ -n "$(file $i | grep -iE "(Linux x86 kernel|Linux kernel x86 boot executable|x86 boot sector)")" ]; then
       # Ugly
-      # we skip memtest
-      if [ -z "$(echo $i | grep -iE "(memtest|eb.zli|memdisk|gpxe.lkn)")" ]; then
+      # we skip memtest, etherboot, freedos...
+      if [ -z "$(echo $i | grep -iE "(memtest|eb.zli|memdisk|gpxe.lkn|freedos|fdos)")" ]; then
         kernel="$i"
         break
       fi
@@ -671,7 +675,7 @@ label $SL_NAME
 SL_PXE
   fi
   # Put the version number
-cat <<-SL_INFO_PXE >> $pxecfg_pd/${SL_NAME}-info.txt
+cat <<-SL_INFO_PXE > $pxecfg_pd/${SL_NAME}-info.txt
 $SL_FULL_NAME version: $SL_VER
 Files were extracted from "$(basename $SL_ISO)"
 SL_INFO_PXE
